"""
OPCUA to ERP5 OPCUA Document setter / getter glue script.
"""

import json
from erp5.component.module.Log import log

def convertNodeValue(node_id, node_value, type_data):
  """
  Based on type_data convert to proper Python type.
  For differentiating different integer types 
  https://docs.pycomm3.dev/en/latest/api_reference/data_types.html
  """
  if "STRING" in type_data:
    # string
    return str(node_value)
  elif "REAL:" in type_data:
    return float(node_value)
  elif "INT" in type_data:
    return int(node_value)
  elif "UINT" in type_data:
    return int(node_value)
  elif "UDINT" in type_data:
    return int(node_value)
  elif "BOOL" in type_data:
    return bool(node_value)
  else: 
    raise ValueError("Unsupported data type %s" % node_value)

# XXX: what should be the OPCUA container?
default_id = "data_stream_1"
default_data_stream = context.portal_catalog.data_stream_module.get(default_id, None)

if default_data_stream is None:
  # Create a new Data Stream if it doesn't exist
  default_data_stream = context.portal_catalog.data_stream_module.newContent(title = "Data Stream 1",
                                            portal_type = "Data Stream",
                                            id = default_id)

# do selection of operation in a REST fashion based in HTTP method
if http_method is None:
  http_method = context.REQUEST.method

if http_method == "GET":
  # not yet implemented
  # assume read request, return  what was saved.
  return json.dumps(default_data_stream.getData())
elif http_method == "POST":
  # assume write request
  if data is None:
    try:
      data = context.REQUEST.data
    except AttributeError as e:
      log("Warning: 'data' is missing from request.")
      raise e
  raw_data = data
  data = json.loads(data)
  if 'node' in data.keys():
    # log only set requests for now
    node_id = data['node']
    node_value = data['val']
    # introspect type of the value
    type_data = data["data"]
    
    # set to "ERP5 OPCUA Document" but only if it's not a None value
    if node_value is not None and node_value != "None":
      converted_value = convertNodeValue(node_id, node_value, type_data)
      default_data_stream.appendData(raw_data)
      log("Data appended to Data Stream: %s" % raw_data)

  return default_data_stream
