#!//usr/bin/python
"""
Basic client with minimal data
"""
import logging
import asyncio
from asyncua import Client, ua
import argparse

# command line handling
parser = argparse.ArgumentParser(description='Run OPCUA Server.')
a = parser.add_argument
a('--ipv6', help='The IPv6 address on which the OPCUA Server runs', default="::")
a('--ipv6-enabled', help='The IPv6 address check whether it is enabled or disabled', default="1")
a('--port', help='The port on which the OPCUA Server runs', default="4840")
a('--xml', help='Path of XML to configure Server. See asyncua doc for more details.', default=None)

args = parser.parse_args()
ipv6 = args.ipv6
ipv6 = "2001:67c:1254:108:404e::a"
ipv6_enabled = args.ipv6_enabled
port = args.port
xml = args.xml

# Server information
if bool(int(ipv6_enabled)):
    url = f"opc.tcp://[{ipv6}]:{port}/PwDC"
    #url = "opc.tcp://[0.0.0.0]:4840/PwDC"

async def main():
  _logger = logging.getLogger(__name__)
  _logger.info("Connecting to %s ...", url)
  async with Client(url=url, timeout=2) as client:
    while True:
      await asyncio.sleep(1)
      # Get the root node
      root = client.get_root_node()

      # Get the objects node
      objects = await root.get_child("0:Objects")

      # Get the Powerfuse object
      powerfuse_obj = await objects.get_child("1:Powerfuse")

      # Get the variables
      machine_status_rot = await powerfuse_obj.get_child("1:Powerfuse_Maschinenstatus_Status_Rot")
      machine_status_gelb = await powerfuse_obj.get_child("1:Powerfuse_Maschinenstatus_Status_Gelb")

      # Read values
      value_rot = await machine_status_rot.read_value()
      value_gelb = await machine_status_gelb.read_value()
      _logger.info(f"Initial values: Rot={value_rot}, Gelb={value_gelb}")

      # Write values
      await machine_status_rot.write_value(True)
      await machine_status_gelb.write_value(False)

      ### write the values to the opcua-to-http-gw-service opc.tcp://[2001:67c:1254:108:404e::9]:4840/freeopcua/server/
      # Currently there is just one 

if __name__ == "__main__":
  logging.basicConfig(level=logging.INFO)
  asyncio.run(main(), debug=False)



