#!//usr/bin/python
"""
Basic server with minimal data
"""

# from https://opcua-asyncio.readthedocs.io/en/latest/usage/get-started/minimal-client.html
import asyncio
import logging
from asyncua import Server, ua
from asyncua.common.methods import uamethod
import argparse
import random

# command line handling
parser = argparse.ArgumentParser(description='Run OPCUA Server.')
a = parser.add_argument
a('--ipv6', help='The IPv6 address on which the OPCUA Server runs', default="::")
a('--ipv6-enabled', help='The IPv6 address check whether it is enabled or disabled', default="1")
a('--port', help='The port on which the OPCUA Server runs', default="4840")
a('--xml', help='Path of XML to configure Server. See asyncua doc for more details.', default=None)

args = parser.parse_args()
ipv6 = args.ipv6
ipv6_enabled = args.ipv6_enabled
port = args.port
xml = args.xml

async def main():
    _logger = logging.getLogger(__name__)
    # setup our server
    server = Server()
    await server.init()

    if bool(int(ipv6_enabled)):
        server.set_endpoint(f"opc.tcp://[{ipv6}]:{port}/PwDC")

    if xml is not None:
        await server.import_xml(xml)

    idx = 1
    # Create an object to hold the variables
    objects = server.get_objects_node()
    powerfuse_obj = await objects.add_object(idx, "Powerfuse")

    # Create variables
    machine_status_rot = await powerfuse_obj.add_variable(idx, "Powerfuse_Maschinenstatus_Status_Rot", False)
    machine_status_gelb = await powerfuse_obj.add_variable(idx, "Powerfuse_Maschinenstatus_Status_Gelb", False)

    # Set the variables as writable
    await machine_status_rot.set_writable()
    await machine_status_gelb.set_writable()

    # Start the server
    _logger.info("Starting server!")
    async with server:
        while True:
            # Randomly change the machine status
            new_status_rot = random.choice([True, False])
            new_status_gelb = random.choice([True, False])

            await machine_status_rot.write_value(new_status_rot)
            await machine_status_gelb.write_value(new_status_gelb)
            val_machine_status_rot = await machine_status_rot.get_value()
            val_machine_status_gelb = await machine_status_gelb.get_value()
            _logger.info("New machine status: Rot=%r, Gelb=%r",
                         val_machine_status_rot,
                         val_machine_status_gelb)
            await asyncio.sleep(1)

if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO)
    asyncio.run(main(), debug=False)
